# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: powerpay_protos/measurement.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'powerpay_protos/measurement.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!powerpay_protos/measurement.proto\x12\x14powerpay.measurement\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcb\x02\n\x0bMeasurement\x12.\n\x06\x65nergy\x18\x01 \x01(\x0b\x32\x1c.powerpay.measurement.EnergyH\x00\x12,\n\x05power\x18\x02 \x01(\x0b\x32\x1b.powerpay.measurement.PowerH\x00\x12,\n\x05state\x18\x03 \x01(\x0b\x32\x1b.powerpay.measurement.StateH\x00\x12\x30\n\x07session\x18\x04 \x01(\x0b\x32\x1d.powerpay.measurement.SessionH\x00\x12?\n\x0fsignal_strength\x18\x05 \x01(\x0b\x32$.powerpay.measurement.SignalStrengthH\x00\x12\x35\n\nrfid_event\x18\x06 \x01(\x0b\x32\x1f.powerpay.measurement.RFIDEventH\x00\x42\x06\n\x04type\"\xcc\x01\n\x06\x45nergy\x12\r\n\x05value\x18\x01 \x01(\x03\x12.\n\x04unit\x18\x02 \x01(\x0e\x32 .powerpay.measurement.EnergyUnit\x12\x35\n\x04type\x18\x03 \x01(\x0e\x32\'.powerpay.measurement.Energy.EnergyType\"L\n\nEnergyType\x12#\n\x1f\x45NERGY_MEASUREMENT_TYPE_NOT_SET\x10\x00\x12\x0c\n\x08LIFETIME\x10\x01\x12\x0b\n\x07SESSION\x10\x02\"E\n\x05Power\x12\r\n\x05value\x18\x01 \x01(\x01\x12-\n\x04unit\x18\x02 \x01(\x0e\x32\x1f.powerpay.measurement.PowerUnit\"\xd8\x03\n\x05State\x12=\n\tenergized\x18\x01 \x01(\x0e\x32*.powerpay.measurement.State.EnergizedState\x12\x37\n\x06online\x18\x02 \x01(\x0e\x32\'.powerpay.measurement.State.OnlineState\x12=\n\tconnected\x18\x03 \x01(\x0e\x32*.powerpay.measurement.State.ConnectedState\x12\x30\n\x06inputs\x18\x04 \x01(\x0b\x32 .powerpay.measurement.InputState\"P\n\x0e\x45nergizedState\x12\x1d\n\x19\x45NERGIZED_STATE_UNDEFINED\x10\x00\x12\r\n\tENERGIZED\x10\x01\x12\x10\n\x0c\x44\x45_ENERGIZED\x10\x02\"B\n\x0bOnlineState\x12\x1a\n\x16ONLINE_STATE_UNDEFINED\x10\x00\x12\n\n\x06ONLINE\x10\x01\x12\x0b\n\x07OFFLINE\x10\x02\"P\n\x0e\x43onnectedState\x12\x1d\n\x19\x43ONNECTED_STATE_UNDEFINED\x10\x00\x12\r\n\tCONNECTED\x10\x01\x12\x10\n\x0c\x44ISCONNECTED\x10\x02\"N\n\nInputState\x12$\n\x17\x63ircuit_breaker_tripped\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x1a\n\x18_circuit_breaker_tripped\"\x80\x02\n\x07Session\x12)\n\x05start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x17session_consumed_energy\x18\x03 \x01(\x0b\x32\x1c.powerpay.measurement.Energy\x12\x31\n\x0bmeter_start\x18\x04 \x01(\x0b\x32\x1c.powerpay.measurement.Energy\x12/\n\tmeter_end\x18\x05 \x01(\x0b\x32\x1c.powerpay.measurement.Energy\"\x8c\x03\n\x0eSignalStrength\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x45\n\x04unit\x18\x02 \x01(\x0e\x32\x37.powerpay.measurement.SignalStrength.SignalStrengthUnit\x12\x42\n\nradio_type\x18\x03 \x01(\x0e\x32..powerpay.measurement.SignalStrength.RadioType\"\x8d\x01\n\x12SignalStrengthUnit\x12 \n\x1cSIGNAL_STRENGTH_UNIT_NOT_SET\x10\x00\x12\x15\n\x11\x44\x45\x43IBEL_MILLIWATT\x10\x01\x12&\n\"RECEIVED_SIGNAL_STRENGTH_INDICATOR\x10\x02\x12\x16\n\x12SIGNAL_NOISE_RATIO\x10\x03\"P\n\tRadioType\x12\x16\n\x12RADIO_TYPE_NOT_SET\x10\x00\x12\x0c\n\x08\x43\x45LLULAR\x10\x01\x12\x08\n\x04WIFI\x10\x02\x12\x08\n\x04LORA\x10\x03\x12\t\n\x05LOCAL\x10\x04\"\x18\n\tRFIDEvent\x12\x0b\n\x03uid\x18\x01 \x01(\x0c*\\\n\nEnergyUnit\x12\x17\n\x13\x45NERGY_UNIT_NOT_SET\x10\x00\x12\r\n\tWATT_HOUR\x10\x01\x12\x12\n\x0eKILO_WATT_HOUR\x10\x02\x12\x12\n\x0eMEGA_WATT_HOUR\x10\x03*K\n\tPowerUnit\x12\x16\n\x12POWER_UNIT_NOT_SET\x10\x00\x12\x08\n\x04WATT\x10\x01\x12\r\n\tKILO_WATT\x10\x02\x12\r\n\tMEGA_WATT\x10\x03\x42\x06Z\x04./pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'powerpay_protos.measurement_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\004./pb'
  _globals['_ENERGYUNIT']._serialized_start=1943
  _globals['_ENERGYUNIT']._serialized_end=2035
  _globals['_POWERUNIT']._serialized_start=2037
  _globals['_POWERUNIT']._serialized_end=2112
  _globals['_MEASUREMENT']._serialized_start=93
  _globals['_MEASUREMENT']._serialized_end=424
  _globals['_ENERGY']._serialized_start=427
  _globals['_ENERGY']._serialized_end=631
  _globals['_ENERGY_ENERGYTYPE']._serialized_start=555
  _globals['_ENERGY_ENERGYTYPE']._serialized_end=631
  _globals['_POWER']._serialized_start=633
  _globals['_POWER']._serialized_end=702
  _globals['_STATE']._serialized_start=705
  _globals['_STATE']._serialized_end=1177
  _globals['_STATE_ENERGIZEDSTATE']._serialized_start=947
  _globals['_STATE_ENERGIZEDSTATE']._serialized_end=1027
  _globals['_STATE_ONLINESTATE']._serialized_start=1029
  _globals['_STATE_ONLINESTATE']._serialized_end=1095
  _globals['_STATE_CONNECTEDSTATE']._serialized_start=1097
  _globals['_STATE_CONNECTEDSTATE']._serialized_end=1177
  _globals['_INPUTSTATE']._serialized_start=1179
  _globals['_INPUTSTATE']._serialized_end=1257
  _globals['_SESSION']._serialized_start=1260
  _globals['_SESSION']._serialized_end=1516
  _globals['_SIGNALSTRENGTH']._serialized_start=1519
  _globals['_SIGNALSTRENGTH']._serialized_end=1915
  _globals['_SIGNALSTRENGTH_SIGNALSTRENGTHUNIT']._serialized_start=1692
  _globals['_SIGNALSTRENGTH_SIGNALSTRENGTHUNIT']._serialized_end=1833
  _globals['_SIGNALSTRENGTH_RADIOTYPE']._serialized_start=1835
  _globals['_SIGNALSTRENGTH_RADIOTYPE']._serialized_end=1915
  _globals['_RFIDEVENT']._serialized_start=1917
  _globals['_RFIDEVENT']._serialized_end=1941
# @@protoc_insertion_point(module_scope)
