# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: powerpay_protos/integration.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'powerpay_protos/integration.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!powerpay_protos/integration.proto\x12\x14powerpay.integration\x1a\x1cgoogle/protobuf/struct.proto\"]\n\x1aIntegrationTemplateRequest\x12?\n\x10integration_type\x18\x01 \x01(\x0e\x32%.powerpay.integration.IntegrationType\"\xc2\x01\n\x13IntegrationTemplate\x12\x38\n\x12integration_config\x18\x01 \x01(\x0b\x32\x1c.powerpay.integration.Schema\x12<\n\x16integration_properties\x18\x02 \x01(\x0b\x32\x1c.powerpay.integration.Schema\x12\x33\n\rdevice_config\x18\x03 \x01(\x0b\x32\x1c.powerpay.integration.Schema\"b\n\x06Schema\x12*\n\tui_schema\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bjson_schema\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"6\n\x13HealthCheckResponse\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xd6\x01\n\x0bIntegration\x12?\n\x10integration_type\x18\x01 \x01(\x0e\x32%.powerpay.integration.IntegrationType\x12\x18\n\x10integration_name\x18\x02 \x01(\t\x12\x33\n\x12integration_config\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x37\n\x16integration_properties\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct*\x9a\x01\n\x0fIntegrationType\x12\x1e\n\x1aINTEGRATION_TYPE_UNDEFINED\x10\x00\x12\x0e\n\nCHIRPSTACK\x10\x01\x12\t\n\x05\x45\x41SEE\x10\x02\x12\x0b\n\x07NETMORE\x10\x03\x12\x08\n\x04OCPP\x10\x04\x12\x08\n\x04MQTT\x10\x05\x12\r\n\tTHINGPARK\x10\x06\x12\n\n\x06RESIOT\x10\x07\x12\x10\n\x0c\x43HIRPSTACKV4\x10\x08\x32\xec\x01\n\x12IntegrationService\x12]\n\x0bHealthCheck\x12!.powerpay.integration.Integration\x1a).powerpay.integration.HealthCheckResponse\"\x00\x12w\n\x16GetIntegrationTemplate\x12\x30.powerpay.integration.IntegrationTemplateRequest\x1a).powerpay.integration.IntegrationTemplate\"\x00\x42\x06Z\x04./pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'powerpay_protos.integration_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\004./pb'
  _globals['_INTEGRATIONTYPE']._serialized_start=755
  _globals['_INTEGRATIONTYPE']._serialized_end=909
  _globals['_INTEGRATIONTEMPLATEREQUEST']._serialized_start=89
  _globals['_INTEGRATIONTEMPLATEREQUEST']._serialized_end=182
  _globals['_INTEGRATIONTEMPLATE']._serialized_start=185
  _globals['_INTEGRATIONTEMPLATE']._serialized_end=379
  _globals['_SCHEMA']._serialized_start=381
  _globals['_SCHEMA']._serialized_end=479
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=481
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=535
  _globals['_INTEGRATION']._serialized_start=538
  _globals['_INTEGRATION']._serialized_end=752
  _globals['_INTEGRATIONSERVICE']._serialized_start=912
  _globals['_INTEGRATIONSERVICE']._serialized_end=1148
# @@protoc_insertion_point(module_scope)
