# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: powerpay_protos/telemetry.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'powerpay_protos/telemetry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from powerpay_protos import measurement_pb2 as powerpay__protos_dot_measurement__pb2
from powerpay_protos import device_pb2 as powerpay__protos_dot_device__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fpowerpay_protos/telemetry.proto\x12\x12powerpay.telemetry\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!powerpay_protos/measurement.proto\x1a\x1cpowerpay_protos/device.proto\"\x9b\x01\n\tTelemetry\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x06\x64\x65vice\x18\x02 \x01(\x0b\x32\x17.powerpay.device.Device\x12\x36\n\x0bmeasurement\x18\x03 \x03(\x0b\x32!.powerpay.measurement.MeasurementB\x06Z\x04./pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'powerpay_protos.telemetry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\004./pb'
  _globals['_TELEMETRY']._serialized_start=154
  _globals['_TELEMETRY']._serialized_end=309
# @@protoc_insertion_point(module_scope)
